Class extends Part

Class constructor($spec : Object; $style : Object; $userActions : Object)
	
	Super:C1705("menubar"; "mb_"; $spec; $style)
	
	This:C1470.menus:=New collection:C1472()
	
	var $menuSpec : Object
	For each ($menuSpec; This:C1470.spec.menus)
		
		// In JSON schema it is not possible to validate uniqueness of
		// specific property values in an array, so we check for unique
		// menu names manually.
		
		var $menuName : Text
		$menuName:=$menuSpec["name"]
		
		If (This:C1470.menus.query("name = :1"; $menuName).pop()=Null:C1517)
			
			var $menu : cs:C1710._Menu
			$menu:=cs:C1710.Menu.new($menuName; $menuSpec; $style; $userActions)
			If ($menu.validate())
				This:C1470.menus.push($menu)
			End if 
			
		End if 
		
	End for each 
	
	
Function validate()->$valid : Boolean
	
	$valid:=(This:C1470.menus.length>0)
	
	
Function effectivelyVisible()->$visible : Boolean
	
	$visible:=This:C1470.visible
	If ($visible)
		$visible:=(This:C1470.menus.query("visible = :1"; True:C214).length>0)
	End if 
	
	
Function layout($controlWidth : Integer; $controlHeight : Integer; \
$originX : Integer; $originY : Integer)
	
	var $menubarStyle; $menuStyle : Object
	$menubarStyle:=This:C1470.style.menubar
	$menuStyle:=This:C1470.style.menu
	
	var $idx : Integer
	var $curX; $curY : Integer
	
	$curX:=$originX+$menuStyle.paddingX
	$curY:=$originY+$menuStyle.paddingY
	
	This:C1470.bounds:=cs:C1710.Rect.new(0; 0; $controlWidth; $menubarStyle.height)
	
	For ($idx; 0; This:C1470.menus.length-1)
		
		var $menu : cs:C1710.Menu
		$menu:=This:C1470.menus[$idx]
		
		If ($menu.visible)
			$menu.bounds:=cs:C1710.Rect.new($curX; $curY; $menuStyle.width; $menuStyle.height)
			$curX:=$curX+$menu.bounds.width+$menuStyle.paddingX
		Else 
			$menu.bounds:=Null:C1517
		End if 
		
	End for 
	
	
Function build()
	
	var $idx : Integer
	For ($idx; 0; This:C1470.menus.length-1)
		
		var $menu : cs:C1710.Menu
		$menu:=This:C1470.menus[$idx]
		
		OBJECT DUPLICATE:C1111(*; "menu"; $menu.formObject)
		OBJECT SET TITLE:C194(*; $menu.formObject; $menu.title)
		OBJECT SET FORMAT:C236(*; $menu.formObject; This:C1470.style.menu.normalFormat)
		
	End for 
	
	
Function apply()
	
	// Menu widths are calculated dynamically from
	// the optimal width of the menu titles
	
	var $menubarStyle; $menuStyle : Object
	$menubarStyle:=This:C1470.style.menubar
	$menuStyle:=This:C1470.style.menu
	
	var $idx : Integer
	var $curX; $curY : Integer
	
	$curX:=$menuStyle.paddingX
	$curY:=$menuStyle.paddingY
	
	var $visibleMenuCount : Integer
	$visibleMenuCount:=This:C1470.menus.query("visible = :1"; True:C214).length
	
	var $menubarVisible : Boolean
	$menubarVisible:=(This:C1470.visible & ($visibleMenuCount>0))
	
	// Menus
	var $idx : Integer
	For ($idx; 0; This:C1470.menus.length-1)
		
		var $menu : cs:C1710.Menu
		$menu:=This:C1470.menus[$idx]
		
		var $bounds : cs:C1710.Rect
		$bounds:=$menu.bounds
		
		If $menubarVisible & ($menu.visible & ($bounds#Null:C1517))
			
			OBJECT SET VISIBLE:C603(*; $menu.formObject; True:C214)
			
			var $bestWidth; $bestHeight : Integer
			OBJECT GET BEST SIZE:C717(*; $menu.formObject; $bestWidth; $bestHeight)
			
			var $actualWidth : Integer
			$actualWidth:=$menuStyle.titleMargin+$bestWidth+$menuStyle.titleMargin
			
			$menu.bounds.x:=$curX
			$menu.bounds.y:=$curY
			$menu.bounds.width:=$actualWidth
			
			OBJECT SET COORDINATES:C1248(*; $menu.formObject; \
				$curX; $curY; \
				$curX+$actualWidth; $curY+$menuStyle.height)
			
			$curX:=$curX+$actualWidth+$menuStyle.paddingX
		Else 
			OBJECT SET VISIBLE:C603(*; $menu.formObject; False:C215)
		End if 
		
	End for 
	
	// Separator
	
	var $left; $top; $right; $bottom : Integer
	$left:=This:C1470.bounds.x
	$top:=This:C1470.bounds.y+This:C1470.bounds.height
	$right:=$left+This:C1470.bounds.width
	$bottom:=$top
	
	OBJECT SET VISIBLE:C603(*; "menubar_sep"; $menubarVisible)
	OBJECT SET COORDINATES:C1248(*; "menubar_sep"; \
		$left; $top; $right; $bottom)
	
	
Function getMenu($name : Text)->$menu : cs:C1710.Menu
	
	$menu:=This:C1470.menus.query("name = :1"; $name).pop()
	
	
Function getMenuFromFormObject($formObject : Text)->$menu : cs:C1710.Menu
	
	$menu:=This:C1470.menus.query("formObject = :1"; $formObject).pop()
	
	