//%attributes = {"shared":true}
C_TEXT:C284($1; $controlName)  // @param: The name of the ``ImgControl`` form object.
C_TEXT:C284($2; $areaName)  // @param: The name of the ``ImgArea`` plug-in area.
C_TEXT:C284($3; $handlerMethod)  // @param: The message handler method. @optional
C_LONGINT:C283($0; $success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

// @desc: Initialize a ImgControl form object.

// @doc: Initialize a ``ImgControl`` form object.
//
// This method must be called before any other calls to an ``ImgControl``
// instance in order to set up the widget's internal context and bind it
// to the plug-in area. Must be balanced with a call to
// :cc4d:cmethod:`ImgControl_Finalize` for cleanup.
//
// Typically called during the ``On Load`` event of the host form.
//
// The names of the `ImgControl`` and ``ImgArea`` form objects are specified
// by the ``controlName`` and ``areaName`` parameters respectively.
//

ASSERT:C1129(Count parameters:C259>=2)

$controlName:=$1
$areaName:=$2
If (Count parameters:C259>2)
	$handlerMethod:=$3
End if 
$success:=0

C_POINTER:C301($contextPtr)
$contextPtr:=OBJECT Get pointer:C1124(Object named:K67:5; $controlName)

C_POINTER:C301($areaPtr)
$areaPtr:=OBJECT Get pointer:C1124(Object named:K67:5; $areaName)

If (Not:C34(Is nil pointer:C315($contextPtr) | Is nil pointer:C315($areaPtr)))
	
	// Locate the control's form page
	ARRAY TEXT:C222($formObjectNames; 0)
	ARRAY POINTER:C280($formObjectVars; 0)
	ARRAY LONGINT:C221($formObjectPages; 0)
	
	FORM GET OBJECTS:C898($formObjectNames; $formObjectVars; $formObjectPages)
	
	C_OBJECT:C1216($controlDict)
	$controlDict:=New object:C1471
	
	C_LONGINT:C283($controlIdx)
	
	For ($controlIdx; 1; Size of array:C274($formObjectNames))
		$controlDict[$formObjectNames{$controlIdx}]:=$formObjectPages{$controlIdx}
	End for 
	
	C_LONGINT:C283($controlPage)
	$controlPage:=$controlDict[$controlName]
	
	C_LONGINT:C283($areaRef)
	$areaRef:=$areaPtr->
	
	// Set default zoom to auto-fit sticky
	C_OBJECT:C1216($defaultZoom)
	$defaultZoom:=OB_New
	OB SET:C1220($defaultZoom; "ZoomFactor"; 1)
	OB SET:C1220($defaultZoom; "AutoZoom"; kImgAreaAutoZoomToFit | kImgAreaAutoZoomStretch | kImgAreaAutoZoomSticky)
	
	//ImgArea_SetProperty ($areaRef;"DefaultZoom";->$defaultZoom)
	
	OBJECT SET VISIBLE:C603(*; $areaName; OBJECT Get visible:C1075(*; $controlName))
	
	C_OBJECT:C1216($context)
	$context:=New object:C1471
	$context.controlName:=$controlName
	$context.areaName:=$areaName
	$context.areaRef:=$areaRef
	$context.formPage:=$controlPage
	$context.initiallyVisible:=OBJECT Get visible:C1075(*; $controlName)
	$context.state:=New object:C1471
	$context.state.formSet:=False:C215
	$context.state.layoutApplied:=False:C215
	$context.state.layoutUpdated:=False:C215
	//$context.state.controlStateUpdated:=False
	
	
	// FIXME: callable thing
	C_BOOLEAN:C305($handlerCallable)
	$handlerCallable:=False:C215
	If (Is compiled mode:C492(*))
		$handlerCallable:=($handlerMethod#"")
	Else 
		If ($handlerMethod#"")
			$handlerCallable:=Comp_CheckCallableMethod($handlerMethod; \
				"which is set as a message handler for Image Controller "+String_Quoted($controlName))
		End if 
	End if 
	If ($handlerCallable)
		$context.messageHandler:=$handlerMethod
	End if 
	
	$contextPtr->:=$context
	
	$success:=1
	
End if 

$0:=$success
