//%attributes = {"shared":true}
C_TEXT:C284($1;$controlName)  // @param: The name of the ``ImgControl`` form object.
C_TEXT:C284($2;$areaName)  // @param: The name of the ``ImgArea`` plug-in area.
C_TEXT:C284($3;$handlerMethod)  // @param: The message handler method. @optional
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Initialize a ImgControl form object.

  // @doc: Initialize a ``ImgControl`` form object.
  //
  // This method must be called before any other calls to an ``ImgControl``
  // instance in order to set up the widget's internal context and bind it
  // to the plug-in area. Must be balanced with a call to
  // :cc4d:cmethod:`ImgControl_Finalize` for cleanup.
  //
  // Typically called during the ``On Load`` event of the host form.
  //
  // The names of the `ImgControl`` and ``ImgArea`` form objects are specified
  // by the ``controlName`` and ``areaName`` parameters respectively.
  //

ASSERT:C1129(Count parameters:C259>=2)

$controlName:=$1
$areaName:=$2
If (Count parameters:C259>2)
	$handlerMethod:=$3
End if 
$success:=0

C_POINTER:C301($contextPtr)
$contextPtr:=OBJECT Get pointer:C1124(Object named:K67:5;$controlName)

If (Ptr_IsValid ($contextPtr))
	
	C_LONGINT:C283($process;$window)
	$process:=Current process:C322
	$window:=Current form window:C827
	
	C_TEXT:C284($contextKey)
	$contextKey:=$controlName+"-"+Substring:C12(String:C10($process;"&X");3)+"-"+Substring:C12(String:C10($window;"&X");3)
	
	$contextPtr->:=$contextKey
	
	C_OBJECT:C1216($context)
	$context:=Context_Create ($contextKey)
	
	If (OB Is defined:C1231($context))
		
		C_POINTER:C301($areaPtr)
		$areaPtr:=OBJECT Get pointer:C1124(Object named:K67:5;$areaName)
		
		C_LONGINT:C283($areaRef)
		$areaRef:=$areaPtr->
		
		  // ==============================
		  // Init area
		
		  // Set default zoom to auto-fit sticky
		C_OBJECT:C1216($defaultZoom)
		$defaultZoom:=OB_New 
		OB SET:C1220($defaultZoom;"ZoomFactor";1)
		OB SET:C1220($defaultZoom;"AutoZoom";kImgAreaAutoZoomToFit | kImgAreaAutoZoomStretch | kImgAreaAutoZoomSticky)
		
		ImgArea_SetProperty ($areaRef;"DefaultZoom";->$defaultZoom)
		
		  // ==============================
		  // Init context
		
		  // Track the control's origin for 4D versions before v15R3
		
		C_TEXT:C284($cvtCoordsName)
		$cvtCoordsName:=Command name:C538(1365)
		If ($cvtCoordsName="")  // (Application version<"1530")
			
			C_OBJECT:C1216($controllerOrigin)
			$controllerOrigin:=RectObj_GetOrigin (FormObj_GetRect ($controlName))
			
			OB SET:C1220($context;"_origin_v15";$controllerOrigin)
		End if 
		
		  // Check the message handler method
		
		C_BOOLEAN:C305($handlerCallable)
		$handlerCallable:=False:C215
		If (Is compiled mode:C492(*))
			$handlerCallable:=($handlerMethod#"")
		Else 
			If ($handlerMethod#"")
				$handlerCallable:=Comp_CheckCallableMethod ($handlerMethod;\
					"which is set as a message handler for Image Controller "+String_Quoted ($controlName))
			End if 
		End if 
		If ($handlerCallable)
			OB SET:C1220($context;"_message_handler";$handlerMethod)
		End if 
		
		  // Track the control visibility:
		  // Hide control and area initially, and show after setup is done
		
		C_BOOLEAN:C305($controlVisible)
		$controlVisible:=OBJECT Get visible:C1075(*;$controlName)
		
		OBJECT SET VISIBLE:C603(*;$controlName;False:C215)
		OBJECT SET VISIBLE:C603(*;$areaName;False:C215)
		
		OB SET:C1220($context;"_control_name";$controlName)
		OB SET:C1220($context;"_area_name";$areaName)
		OB SET:C1220($context;"_area_ref";$areaRef)
		
		OB SET:C1220($context;"_menubar_visible";True:C214)
		OB SET:C1220($context;"_toolbar_visible";True:C214)
		OB SET:C1220($context;"_sidebar_visible";False:C215)
		
		OB SET:C1220($context;"_control_visible";$controlVisible)
		
		EXECUTE METHOD IN SUBFORM:C1085($controlName;"Control_Initialize_S";*;$context)
		
		$success:=1
		
	End if 
	
End if 

$0:=$success
