//%attributes = {"shared":true}
C_LONGINT:C283($1; $areaRef)  // @param: The image area reference.
C_POINTER:C301($2; $effectNamePtr)  // @param: Pointer to the effect name. @optional
C_POINTER:C301($3; $effectParamsPtr)  // @param: Pointer to the effect parameters. @optional
C_LONGINT:C283($0; $success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

// @desc: Display a dialog where the user can select and apply an effect to the
// raster image displayed in a plug-in area.

// @doc: Display a dialog where the user can select and apply an effect to the
// raster image displayed in a plug-in area.
//
// The optional parameters ``effectNamePtr`` and ``effectParamsPtr`` are pointers to text and object
// respectively. On entry, they may specify the effect name and parameters to be initially
// selected in the dialog. If the user accepts the dialog, they receive the selected
// name effect and parameters.
//
// If the user accepts the dialog the selected effect is applied to the image in the area
// and the method returns ``1``. Otherwise, the method returns ``0``.

ASSERT:C1129(Count parameters:C259>=1)

$areaRef:=$1
If (Count parameters:C259>1)
	$effectNamePtr:=$2
End if 
If (Count parameters:C259>2)
	$effectParamsPtr:=$3
End if 
$success:=0

C_TEXT:C284(pEffectNameArg)
C_OBJECT:C1216(pEffectParamsArg)

If (Not:C34(Is nil pointer:C315($effectNamePtr)))
	pEffectNameArg:=$effectNamePtr->
End if 

If (Not:C34(Is nil pointer:C315($effectParamsPtr)))
	pEffectParamsArg:=$effectParamsPtr->
End if 

C_TEXT:C284(_pEffectDoc)
_pEffectDoc:=ImgArea_GetDocument:P11667:41($areaRef)

C_LONGINT:C283(_pEffectFrameIdx)
_pEffectFrameIdx:=ImgArea_GetFrameIndex:P11667:42($areaRef)

_RasterEffect_LoadSpecs

If ((_pEffectDoc#"") & (ImgDoc_GetFormat:P11667:9(_pEffectDoc)#"PDF") & (Size of array:C274(pEffectNames)>0))
	
	C_LONGINT:C283($effectIdx)
	$effectIdx:=Find in array:C230(pEffectNames; pEffectNameArg)
	If ($effectIdx<=0)
		
		pEffectNameArg:=pEffectNames{1}
		
	Else 
		
		If (OB Is defined:C1231(pEffectParamsArg))
			
			C_OBJECT:C1216($effectSpec)
			$effectSpec:=OB Get:C1224(pDialogEffects; pEffectNameArg; Is object:K8:27)
			
			C_OBJECT:C1216($paramValues)
			$paramValues:=OB Get:C1224($effectSpec; "ParamValues"; Is object:K8:27)
			
			$paramValues:=OB_SimpleMerge($paramValues; pEffectParamsArg)
			OB SET:C1220($effectSpec; "ParamValues"; $paramValues)
			
		End if 
		
	End if 
	
	C_LONGINT:C283(pEffectWindow)
	pEffectWindow:=Open form window:C675("_ImgAreaEffect"; Movable form dialog box:K39:8; Horizontally centered:K39:1; Vertically centered:K39:4)
	
	DIALOG:C40("_ImgAreaEffect")
	If (OK=1)
		
		If (Not:C34(Is nil pointer:C315($effectNamePtr)))
			$effectNamePtr->:=pEffectNameArg
		End if 
		
		If (Not:C34(Is nil pointer:C315($effectParamsPtr)))
			$effectParamsPtr->:=OB Copy:C1225(pEffectParamsArg)
		End if 
		
		$success:=1
		
	End if 
	
	CLOSE WINDOW:C154(pEffectWindow)
	pEffectWindow:=0
	
End if 

If (_pEffectDoc#"")
	ImgObj_Release:P11667:133(_pEffectDoc)
	_pEffectDoc:=""
End if 

$0:=$success
