//%attributes = {"invisible":true,"shared":true}
C_TEXT:C284($1; $docRef)
C_LONGINT:C283($2; $frameIdx)  // @optional
C_LONGINT:C283($0; $edited)

// @doc: Displays a dialog allowing the user to edit the image frame's resolution
// (pixels per inch).
//
// .. note:: This method is applicable only to raster images. PDF pages and other
//           vector based formats do not have an explicit resolution attribute.
//           Their implicit resolution is infinity.
//
// If the user successfully edited the image's horizontal and vertical resolution
// values and accepted the dialog, the modification is applied to the image frame
// and the method returns True.
//
// If the user cancels the dialog or there is some error, the method returns ``0``.
//
// .. note:: The resolution modifications are applied to the image frame "in memory";
//           the image document must be saved in order for the changes to be applied
//           permanently.
//
// Parameter docRef is the image document reference.
//
// Parameter frameIdx is the index of the image frame. Passing ``0`` or omitting this
// argument is the same as passing 1.
//


$docRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
Else 
	$frameIdx:=0
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

$edited:=0

C_TEXT:C284($format)
$format:=ImgDoc_GetFormat:P11667:9($docRef)

If (($format#"") & ($format#"PDF"))
	
	C_OBJECT:C1216($dpiSize)
	$dpiSize:=RasterFrame_GetDPISize($docRef; $frameIdx)
	
	C_REAL:C285(pImgHorzRes; pImgVertRes)
	pImgHorzRes:=Choose:C955($dpiSize["Width"]#Null:C1517; $dpiSize["Width"]; 0)
	pImgVertRes:=Choose:C955($dpiSize["Height"]#Null:C1517; $dpiSize["Height"]; 0)
	
	If ((ImgErr_GetCode=0) & (pImgHorzRes>=1) & (pImgVertRes>=1))
		
		C_LONGINT:C283(pImgResWindow)
		pImgResWindow:=Open form window:C675("_ImgResolution"; Movable form dialog box:K39:8; Horizontally centered:K39:1; Vertically centered:K39:4)
		SET WINDOW TITLE:C213("Change resolution"; pImgResWindow)
		DIALOG:C40("_ImgResolution")
		If ((OK=1) & (pImgHorzRes>=1) & (pImgVertRes>=1))
			
			OB SET:C1220($dpiSize; "Width"; pImgHorzRes)
			OB SET:C1220($dpiSize; "Height"; pImgVertRes)
			
			RasterFrame_SetDPISize($docRef; $frameIdx; $dpiSize)
			
			$edited:=1
			
		End if 
		
		CLOSE WINDOW:C154(pImgResWindow)
		
	End if 
	
End if 

$0:=$edited
