//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The image document reference.
C_POINTER:C301($2;$savingOptionsPtr)  // @param: Pointer to the format options object.
C_POINTER:C301($3;$formatListPtr)  // @param: Pointer to the array of format iDs. @optional
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Display the image format saving options dialog.

  // @doc: Display the image format saving options dialog for an image document,
  // and return the options selected by the user.
  //
  // Parameter ``imgDocRef`` is the reference to the image document for which
  // to display the saving options.
  //
  // If ``imgDocRef`` is a valid image document reference, the options displayed in 
  // the dialog are adjusted to the characteristics and edited state of the document.
  // 
  // ``imgDocRef`` may be an NULL reference (an empty string), in which case the
  // dialog displays generic saving options for the selected format.
  //
  // The ``savingOptionsPtr`` parameter is a pointer to a 4D object containing
  // the saving options. On entry, these options are used to set the initial state of
  // the dialog. On successful completion, the 4D object will contain the options
  // selected by the user.
  //
  // The options 4D object may contain the encoding properties supported by the
  // :cc4d:cmethod:`ImgDoc_SaveInBLOB` method.
  //
  // The optional ``formatListPtr`` parameter is a pointer to a text array containing
  // the identifiers of the formats that will be available in the dialog. Can be
  // used to restrict the available export formats. If not specified, all supported
  // formats are listed.
  //
  // If the user accepts the dialog, ``1`` is returned in ``success``, ``0`` otherwise.
  //

ASSERT:C1129(Count parameters:C259>=2)

$imgDocRef:=$1
$savingOptionsPtr:=$2
If (Count parameters:C259>2)
	$formatListPtr:=$3
End if 

$success:=0

ASSERT:C1129(Not:C34(Is nil pointer:C315($savingOptionsPtr)))
ASSERT:C1129(Type:C295($savingOptionsPtr->)=Is object:K8:27)

C_OBJECT:C1216($formatOptions)
If (OB Is defined:C1231($savingOptionsPtr->))
	$formatOptions:=$savingOptionsPtr->
End if 

C_LONGINT:C283($frameCount)
$frameCount:=ImgDoc_GetFrameCount:P11667:11 ($imgDocRef)

ARRAY TEXT:C222(pExportFormatIDs;0)
ARRAY TEXT:C222(pExportFormatNames;0)
ImgFormat_GetEncoders (->pExportFormatIDs;->pExportFormatNames)
SORT ARRAY:C229(pExportFormatNames;pExportFormatIDs;>)

If (Not:C34(Is nil pointer:C315($formatListPtr)))
	
	C_LONGINT:C283($idx)
	For ($idx;Size of array:C274(pExportFormatIDs);1;-1)
		If (Find in array:C230($formatListPtr->;pExportFormatIDs{$idx})<=0)
			DELETE FROM ARRAY:C228(pExportFormatIDs;$idx)
			DELETE FROM ARRAY:C228(pExportFormatNames;$idx)
		End if 
	End for 
	
End if 

If (Size of array:C274(pExportFormatIDs)>0)
	
	C_TEXT:C284(pSaveDoc)
	pSaveDoc:=$imgDocRef
	
	C_BOOLEAN:C305(pSaveMultiframe)
	pSaveMultiframe:=($frameCount>1)
	
	C_OBJECT:C1216(pFormatOptions)
	If (OB Is defined:C1231($formatOptions))
		pFormatOptions:=OB Copy:C1225($formatOptions)
	Else 
		pFormatOptions:=$formatOptions  // Initialize to undefined
	End if 
	
	C_LONGINT:C283(pFormatOptionsWindow)
	pFormatOptionsWindow:=Open form window:C675("_SaveOptions";Movable form dialog box:K39:8;Horizontally centered:K39:1;Vertically centered:K39:4)
	SET WINDOW TITLE:C213("Format options";pFormatOptionsWindow)
	DIALOG:C40("_SaveOptions")
	If (OK=1)
		
		$savingOptionsPtr->:=OB Copy:C1225(pFormatOptions)
		$success:=1
		
	End if 
	CLOSE WINDOW:C154(pFormatOptionsWindow)
	
End if 

$0:=$success
