//%attributes = {"invisible":true}
C_TEXT:C284($1; $imgDocRef)  // @param: The image document reference.

// @desc: Copy the image document to the pasteboard.

// @doc: Copy the image document to the pasteboard.
// 
// Parameter ``imgDocRef`` is the image document reference.
// 

ASSERT:C1129(Count parameters:C259=1)

$imgDocRef:=$1

C_LONGINT:C283($frameCount)
$frameCount:=ImgDoc_GetFrameCount:P11667:11($imgDocRef)

If ($frameCount>0)
	
	C_TEXT:C284($docFormat)
	$docFormat:=ImgDoc_GetFormat:P11667:9($imgDocRef)
	
	C_OBJECT:C1216($formatInfo)
	$formatInfo:=ImgFormat_GetInfo($docFormat)
	
	If ($docFormat="PDF")
		
	Else   // Raster image
		
		C_LONGINT:C283($docMods)
		$docMods:=ImgDoc_GetEditsSummary:P11667:14($imgDocRef)
		
		If ($docMods=0)  // Not modified
			
			If (Is macOS:C1572)  // Mac: put original data on pasteboard
				
				C_BLOB:C604($docData)
				// FIXME: private API
				//$docData:=@ImgDoc_GetData ($imgDocRef)
				
				If (BLOB size:C605($docData)>0)
					
					C_TEXT:C284($docUTI)
					$docUTI:=OB Get:C1224($formatInfo; "UTI"; Is text:K8:3)
					
					CLEAR PASTEBOARD:C402
					APPEND DATA TO PASTEBOARD:C403($docUTI; $docData)
					
				End if 
				
			Else   // Windows: put TIFF
				
				C_OBJECT:C1216($exportOptions)
				OB SET:C1220($exportOptions; "Format"; "TIFF")
				
				C_BLOB:C604($tiffData)
				$tiffData:=ImgDoc_SaveInBLOB($imgDocRef; $exportOptions)
				If (BLOB size:C605($tiffData)>0)
					
					C_PICTURE:C286($tiffPict)
					BLOB TO PICTURE:C682($tiffData; $tiffPict)
					
					If (Picture size:C356($tiffPict)>0)
						
						SET PICTURE TO PASTEBOARD:C521($tiffPict)
						
					End if 
					
				End if 
				
			End if 
			
		Else   // Doc modified
			
			C_BOOLEAN:C305($canEncode)
			$canEncode:=OB Get:C1224($formatInfo; "CanEncode"; Is boolean:K8:9)
			
			C_TEXT:C284($encodeFormat)
			If (Is macOS:C1572)
				$encodeFormat:=Choose:C955($canEncode; $docFormat; "TIFF")
			Else 
				$encodeFormat:="TIFF"
			End if 
			
			C_OBJECT:C1216($pbFormatInfo)
			$pbFormatInfo:=ImgFormat_GetInfo($encodeFormat)
			
			C_OBJECT:C1216($encodeOptions)
			OB SET:C1220($encodeOptions; "Format"; $encodeFormat)
			
			C_BLOB:C604($encodedData)
			$encodedData:=ImgDoc_SaveInBLOB($imgDocRef; $encodeOptions)
			If (BLOB size:C605($encodedData)>0)
				
				C_TEXT:C284($pbUTI)
				$pbUTI:=OB Get:C1224($pbFormatInfo; "UTI"; Is text:K8:3)
				
				If (Is macOS:C1572 & ($pbUTI#""))
					
					CLEAR PASTEBOARD:C402
					APPEND DATA TO PASTEBOARD:C403($pbUTI; $encodedData)
					
				Else 
					C_PICTURE:C286($encodedPict)
					BLOB TO PICTURE:C682($encodedData; $encodedPict)
					
					If (Picture size:C356($encodedPict)>0)
						
						SET PICTURE TO PASTEBOARD:C521($encodedPict)
						
					End if 
				End if 
				
			End if 
			
		End if 
		
	End if 
	
End if   // ($frameCount>0)

