//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The image document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The image frame index.
C_TEXT:C284($3;$srcDocRef)  // @param: The source image document reference.
C_LONGINT:C283($4;$srcFrameIdx)  // @param: The source image frame index.
C_OBJECT:C1216($5;$options)  // @param: Options. @optional
C_LONGINT:C283($0;$success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

  // @desc: Insert an image frame to an image document.

  // @doc: Insert an image frame to an image document.
  //
  // Parameter ``imgDocRef`` is the reference to the image document that will receive the
  // new frame. Parameter ``frameIdx`` is the index in the document's frame array where the
  // new frame will be inserted.
  //
  // Parameter ``srcDocRef`` is the reference of the source image document.
  // Parameter ``srcFrameIdx`` is the index of the source frame.
  //
  // Note that ``srcDocRef`` may be the same as ``imgDocRef``, in which case the image frame is
  // duplicated within the same document.
  //
  // Parameter ``options`` is optional, and can be used to specify the rendering resolution
  // (DPI size) when inserting a page from a PDF document into a raster document.
  // It is a 4D object and may contain the following property and value:
  //
  // .. list-table::
  //    :widths: 25 10 20 45
  //    :header-rows: 1
  // 
  //    * - Property name
  //      - Type
  //      - Default
  //      - Description
  //    * - ``RenderDPISize``
  //      - ``SizeObj`` object
  //      - ``{"Width": 300, "Height": 300}``
  //      - The resolution at which the PDF page will be rendered.
  //
  // If the method completes successfully, ``1`` is returned in ``success``, ``0`` otherwise.
  //
  // .. note:: This method is a convenience wrapper for the :cc4d:xmethod:`ImgDoc_InsertFrame_JSN`
  //           plug-in method.
  //

ASSERT:C1129(Count parameters:C259>=4)

$imgDocRef:=$1
$frameIdx:=$2
$srcDocRef:=$3
$srcFrameIdx:=$4
If (Count parameters:C259>4)
	$options:=$5
End if 

C_TEXT:C284($optionsJSON)
If (OB Is defined:C1231($options))
	$optionsJSON:=JSON Stringify:C1217($options)
End if 

$success:=ImgDoc_InsertFrame_JSN:P11667:12 ($imgDocRef;$frameIdx;$srcDocRef;$srcFrameIdx;$optionsJSON)

$0:=$success
