//%attributes = {"shared":true}
C_TEXT:C284($1; $imgDocRef)  // @param: The image document reference.
C_OBJECT:C1216($2; $options)  // @param: Printing options. @optional
C_LONGINT:C283($0; $success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

// @desc: Print the image document.

// @doc: Print the image document.
// 
// Parameter ``imgDocRef`` is the image document reference.
// 
// The optional parameter ``options`` is a 4D object through which printing options
// can be specified:
// 
// .. include:: /_shared/ImgDoc_Print_Options.rsti
// 

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$options:=$2
End if 
$success:=0

C_LONGINT:C283($frameCount)
$frameCount:=ImgDoc_GetFrameCount:P11667:11($imgDocRef)

If ($frameCount>0)  // Valid doc?
	
	C_BOOLEAN:C305($showDialog)
	C_LONGINT:C283($firstPage; $lastPage)
	
	$showDialog:=Choose:C955($options["ShowDialog"]#Null:C1517; Bool:C1537($options["ShowDialog"]); True:C214)
	$firstPage:=Choose:C955($options["FirstPage"]#Null:C1517; Num:C11($options["FirstPage"]); 1)
	$lastPage:=Choose:C955($options["LastPage"]#Null:C1517; Num:C11($options["LastPage"]); -1)
	
	// Save page range
	C_LONGINT:C283($savedFirstPage; $savedLastPage)
	If (Application version:C493>="1600")
		GET PRINT OPTION:C734(15; $savedFirstPage; $savedLastPage)  // Page range option
	End if 
	
	// Save print job title
	C_TEXT:C284($savedSpoolName)
	GET PRINT OPTION:C734(Spooler document name option:K47:10; $savedSpoolName)
	
	C_BOOLEAN:C305($continue)
	$continue:=True:C214
	
	If ($showDialog)
		
		If (Application version:C493>="1600")
			SET PRINT OPTION:C733(15; $firstPage; $lastPage)  // Page range option
		End if 
		
		PRINT SETTINGS:C106
		$continue:=(OK=1)
		
	End if 
	
	If ($continue)
		
		// Get page range
		If (Application version:C493>="1600")
			GET PRINT OPTION:C734(15; $firstPage; $lastPage)  // Page range option
		End if 
		If ($lastPage=-1)
			$lastPage:=$frameCount
		End if 
		If ($lastPage>$frameCount)
			$lastPage:=$frameCount
		End if 
		
		// Setup print job title
		C_TEXT:C284($docPath)
		$docPath:=ImgDoc_GetFilePath($imgDocRef)
		If ($docPath#"")
			
			var $docFile : 4D:C1709.File
			$docFile:=File:C1566($docPath; fk posix path:K87:1)
			
			C_TEXT:C284($docName)
			$docName:=$docFile.fullName
			
			SET PRINT OPTION:C733(Spooler document name option:K47:10; $docName)
			
		Else 
			//SET PRINT OPTION(Spooler document name option;"")
		End if 
		
		// Setup GDI option on v16+/64 bit/Windows
		C_LONGINT:C283($savedGDIOption)
		If (Is Windows:C1573 & (Application version:C493>="1600"))
			GET PRINT OPTION:C734(16; $savedGDIOption)  // Legacy printing layer option
			SET PRINT OPTION:C733(16; 1)  // Legacy printing layer option
		End if 
		
		//If (Platform_IsMac )
		//SET PRINT OPTION(Hide printing progress option;1)
		//End if 
		
		C_LONGINT:C283($pageCount)
		$pageCount:=$lastPage-$firstPage+1
		
		If (Application version:C493>="1600")
			SET PRINT OPTION:C733(15; 1; $pageCount)
		End if 
		
		OPEN PRINTING JOB:C995
		
		C_TEXT:C284(pPrintDocRef)
		pPrintDocRef:=$imgDocRef
		C_LONGINT:C283(pPrintFrameIdx)
		For (pPrintFrameIdx; $firstPage; $lastPage)
			
			Print form:C5("_ImgPrint")
			
			If (pPrintFrameIdx<$lastPage)
				PAGE BREAK:C6(>)
			End if 
			
		End for 
		
		CLOSE PRINTING JOB:C996
		
		// Restore GDI option on v16+/64 bit/Windows
		If (Is Windows:C1573 & (Application version:C493>="1600"))
			SET PRINT OPTION:C733(16; $savedGDIOption)  // Legacy printing layer option
		End if 
		
		// Resore print job title
		SET PRINT OPTION:C733(Spooler document name option:K47:10; $savedSpoolName)
		
	End if 
	
	If (Application version:C493>="1600")
		SET PRINT OPTION:C733(15; $savedFirstPage; $savedLastPage)  // Page range option
	End if 
	
End if 

$0:=$success
