//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame. @optional
C_BOOLEAN:C305($3;$oriented)  // @param: Return the pixel size in the oriented image coordinate space. @optional
C_OBJECT:C1216($0;$pixelSize)  // @param: The image frame's pixel size.

  // @desc: Return the pixel size of a raster frame.

  // @doc: Return the pixel size of the raster frame specified by ``imgDocRef`` and ``frameIdx``.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, an undefined 4D object is returned.
  //
  // Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
  // parameter is the same as passing 1.
  //
  // The optional ``oriented`` parameter specified whether to return the frame's pixel size
  // in the oriented or raw image coordinate space. The default value is ``True``.
  //
  // The raster frame's pixel size is returned in ``pixelSize`` as a ``SizeObj`` object.
  //

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

If (Count parameters:C259>2)
	$oriented:=$3
Else 
	$oriented:=True:C214
End if 

C_OBJECT:C1216($geometry)
$geometry:=ImgFrame_GetGeometry ($imgDocRef;$frameIdx)
If (OB Is defined:C1231($geometry))
	
	$pixelSize:=OB Get:C1224($geometry;"PixelSize";Is object:K8:27)
	If (OB Is defined:C1231($pixelSize) & $oriented)
		
		C_LONGINT:C283($orientation)
		$orientation:=OB Get:C1224($geometry;"Orientation";Is longint:K8:6)
		If (($orientation=kImgRotatedLeft) | ($orientation=kImgRotatedRight) | ($orientation=kImgRotatedLeftFlippedVert) | ($orientation=kImgRotatedRightFlippedVert))
			
			C_LONGINT:C283($width;$height)
			$width:=OB Get:C1224($pixelSize;"Width";Is longint:K8:6)
			$height:=OB Get:C1224($pixelSize;"Height";Is longint:K8:6)
			
			OB SET:C1220($pixelSize;"Width";$height;"Height";$width)
			
		End if 
		
	End if 
	
End if 

$0:=$pixelSize
