//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame.
C_TEXT:C284($3;$filterName)  // @param: The name of the filter.
C_OBJECT:C1216($4;$filterParams)  // @param: The filter parameters. @optional

  // @desc: Modify a raster frame with a filter.

  // @doc: Modify the raster frame specified by ``imgDocRef`` and ``frameIdx`` by
  // pushing a filter and its associated parameters into the frame's edit stack.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, this method does nothing.
  //
  // Parameter ``frameIdx`` is the index of the image frame.
  //
  // The filter is specified by the ``filterName`` and ``filterParams`` parameters.
  // If the specified filter does not take any parameters, or to use the filter's
  // default parameter values, ``filterParams`` may be omitted.
  //
  // For a description on how filters are used for editing raster frames,
  // see :ref:`Raster Image Filters <guide-raster-filters>` in the programming guide.
  //
  // Supported filters and their associated parameters are listed in the
  // :ref:`Raster Filter Reference <ref-raster-filters>` section.
  // 

ASSERT:C1129(Count parameters:C259>=3)

$imgDocRef:=$1
$frameIdx:=$2
$filterName:=$3
If (Count parameters:C259>3)
	$filterParams:=$4
End if 

C_TEXT:C284($paramsJSON)
If (OB Is defined:C1231($filterParams))
	$paramsJSON:=JSON Stringify:C1217($filterParams)
End if 

RasterFrame_PushFilter_JSN:P11667:28 ($imgDocRef;$frameIdx;$filterName;$paramsJSON)

