//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame.
C_OBJECT:C1216($3;$pixelSize)  // @param: The new pixel size of the frame.
C_OBJECT:C1216($4;$dpiSize)  // @param: The new DPI size of the frame.
C_BOOLEAN:C305($5;$oriented)  // @param: Whether ``pixelSize`` and ``dpiSize`` are expressed in the oriented or raw image coordinate space. @optional

  // @desc: Change the size of a raster frame.

  // @doc: Change the size of the raster frame 
  // by modifying its pixel side and/or resolution.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, this method does nothing.
  //
  // Parameter ``frameIdx`` is the index of the image frame.
  //
  // The new pixel size is specified by the ``pixelSize`` parameter, which is a ``SizeObj`` object.
  // If ``pixelSize`` is not equal to the current pixel size, the frame pixel map is resampled
  // to the new pixel size
  // by applying the "Scale" filter with appropriate horizontal and vertical scale factors.
  //
  // The new resolution may be specified by ``dpiSize``, which is also a ``SizeObj`` object
  // with its ``Width`` and ``Height`` properties representing
  // the new horizontal and vertical resolution, expressed in ``pixels per inch``. If ``dpiSize``
  // is not equal to the current resolution, the "Resolution" filter is applied.
  // If this parameter is omitted or an undefined object, the current resolution is not affected.
  //
  // Parameter ``oriented`` specifies whether ``pixelSize`` and ``dpiSize``
  // be expressed in the oriented or in the raw image frame coordinate space.
  // Optional, default is ``True``.

ASSERT:C1129(Count parameters:C259>=3)

$imgDocRef:=$1
$frameIdx:=$2
If (Count parameters:C259>2)
	$pixelSize:=$3
End if 
If (Count parameters:C259>3)
	$dpiSize:=$4
End if 
If (Count parameters:C259>4)
	$oriented:=$5
Else 
	$oriented:=True:C214
End if 

C_OBJECT:C1216($curPixelSize;$curDPISize)
$curPixelSize:=RasterFrame_GetPixelSize ($imgDocRef;$frameIdx)
$curDPISize:=RasterFrame_GetDPISize ($imgDocRef;$frameIdx)

If (Not:C34(OB Is defined:C1231($pixelSize)))
	$pixelSize:=$curPixelSize
End if 

If (Not:C34(OB Is defined:C1231($dpiSize)))
	$dpiSize:=$curDPISize
End if 

If (OB Is defined:C1231($pixelSize)\
 & OB Is defined:C1231($dpiSize)\
 & OB Is defined:C1231($curPixelSize)\
 & OB Is defined:C1231($curDPISize))
	
	C_LONGINT:C283($curPixelWidth;$curPixelHeight)
	$curPixelWidth:=SizeObj_GetWidth ($curPixelSize)
	$curPixelHeight:=SizeObj_GetHeight ($curPixelSize)
	
	C_LONGINT:C283($curDPIWidth;$curDPIHeight)
	$curDPIWidth:=SizeObj_GetWidth ($curDPISize)
	$curDPIHeight:=SizeObj_GetHeight ($curDPISize)
	
	C_LONGINT:C283($newPixelWidth;$newPixelHeight)
	$newPixelWidth:=SizeObj_GetWidth ($pixelSize)
	$newPixelHeight:=SizeObj_GetHeight ($pixelSize)
	
	C_LONGINT:C283($newDPIWidth;$newDPIHeight)
	$newDPIWidth:=SizeObj_GetWidth ($dpiSize)
	$newDPIHeight:=SizeObj_GetHeight ($dpiSize)
	
	If (($newPixelWidth>0)\
		 & ($newPixelHeight>0)\
		 & ($newDPIWidth>=1)\
		 & ($newDPIHeight>=1))
		
		
		If (($newPixelWidth#$curPixelWidth) | ($newPixelHeight#$curPixelHeight))
			
			C_REAL:C285($scaleX;$scaleY)
			$scaleX:=$newPixelWidth/$curPixelWidth
			$scaleY:=$newPixelHeight/$curPixelHeight
			
			RasterFrame_Scale ($imgDocRef;$frameIdx;$scaleX;$scaleY;$oriented)
			
		End if 
		
		If (($newDPIWidth#$curDPIWidth) | ($newDPIHeight#$curDPIHeight))
			
			RasterFrame_SetDPISize ($imgDocRef;$frameIdx;\
				SizeObj_New ($newDPIWidth;$newDPIHeight);$oriented)
			
		End if 
		
	Else 
		
		C_OBJECT:C1216($errInfo)
		OB SET:C1220($errInfo;"Domain";"Q2Pix";"Code";kQ2PixErrInvalid;\
			"Method";Current method name:C684)
		ImgErr_SetInfo ($errInfo)
		
	End if 
	
Else 
	
	C_OBJECT:C1216($errInfo)
	OB SET:C1220($errInfo;"Domain";"Q2Pix";"Code";kQ2PixErrInvalid;\
		"Method";Current method name:C684)
	ImgErr_SetInfo ($errInfo)
	
End if 

