//%attributes = {"shared":true}
C_TEXT:C284($1;$imgDocRef)  // @param: The raster document reference.
C_LONGINT:C283($2;$frameIdx)  // @param: The index of the raster frame. @optional

  // @desc: Rotate the orientation of the raster frame to the left.

  // @doc: Change the orientation property of the raster frame so that it gets
  // rotated 90º counter-clockwise from its current orientation.
  //
  // Parameter ``imgDocRef`` is the raster document reference. If ``imgDocRef`` refers
  // to a PDF document, this method does nothing.
  //
  // Parameter ``frameIdx`` is the index of the image frame. Passing ``0`` or omitting this
  // parameter is the same as passing 1.
  //
  // .. note:: This method does not modify the raster frame's pixels, but rather changes
  //           the frame's ``orientation`` property to reflect the requested transformation.
  //
  // .. note:: This is a convenience method built on top of the :cc4d:cmethod:`RasterFrame_SetOrientation`
  //           method.
  //

ASSERT:C1129(Count parameters:C259>=1)

$imgDocRef:=$1
If (Count parameters:C259>1)
	$frameIdx:=$2
End if 

If ($frameIdx=0)
	$frameIdx:=1
End if 

C_LONGINT:C283($orientation;$newOrientation)
$orientation:=RasterFrame_GetOrientation ($imgDocRef;$frameIdx)
If (ImgErr_GetCode =0)
	$newOrientation:=<>kImgOrientationTransitions{$orientation}{1}
	If ($newOrientation#$orientation)
		RasterFrame_SetOrientation ($imgDocRef;$frameIdx;$newOrientation)
	End if 
End if 
