//%attributes = {"shared":true}
C_TEXT:C284($1; $xmpDataRef)  // @param: The XMP data reference to be edited.
C_OBJECT:C1216($2; $options)  // @param: Editor options @optional
C_LONGINT:C283($0; $success)  // @param: Completion status: ``1`` on success, ``0`` otherwise.

// @desc: Invoke the XMP Editor dialog.

// @doc: Invoke the XMP Editor dialog.
//
// Parameter ``xmpDataRef`` is the reference of the XMP data to be edited.
//
// The optional ``options`` object parameter can be used for passing
// options to the editor. The following properties can be used:
//
// .. list-table:: XMP Editor Options
//    :widths: 25 10 20 45
//    :header-rows: 1
//
//    * - Property name
//      - Type
//      - Default
//      - Description
//    * - ``WindowTitle``
//      - ``String``
//      - ``"XMP Metadata"``
//      - The window title of the editor dialog.
//    * - ``EditProps``
//      - ``String``
//      - ``"Spec"``
//      - The editability of the properties in the XMP data.
//        ``"Spec"`` means according to the specification,
//        ``"All"`` means all properties editable, and
//        ``"None"`` means no properties editable.
//    * - ``DevMode``
//      - ``Boolean``
//      - ``False``
//      - Set to ``True`` to enable the developer mode in the editor.
//
// If the user accepts the editing dialog, the method returns ``1`` in
// ``success``, otherwise ``0`` is returned.
//

ASSERT:C1129(Count parameters:C259>=1)

$xmpDataRef:=$1
If (Count parameters:C259>1)
	$options:=$2
End if 

$success:=0

Lib_LazyInit

// Validate data ref
ARRAY TEXT:C222($propNames; 0)
XMPData_GetPropertyNames:P11667:80($xmpDataRef; ""; $propNames)
If (ImgErr_GetCode=0)
	
	// No refcount semantics on this here, just used for passing
	// the data ref to the form.
	C_TEXT:C284(pXMPEditDataRef)
	pXMPEditDataRef:=$xmpDataRef
	
	// We need this for passing options to the form.
	C_OBJECT:C1216(pXMPEditOptions)
	pXMPEditOptions:=New object:C1471()
	
	// "EditProps": "Spec", "All", "None"
	C_TEXT:C284($editProps)
	$editProps:=Choose:C955($options["EditProps"]#Null:C1517; $options["EditProps"]; "Spec")
	
	C_BOOLEAN:C305($devMode)
	$devMode:=Choose:C955($options["DevMode"]#Null:C1517; Bool:C1537($options["DevMode"]); False:C215)
	
	OB SET:C1220(pXMPEditOptions; "EditProps"; $editProps)
	OB SET:C1220(pXMPEditOptions; "DevMode"; $devMode)
	
	C_TEXT:C284($windowTitle)
	$windowTitle:=Choose:C955($options["WindowTitle"]#Null:C1517; $options["WindowTitle"]; "XMP Metadata")
	
	C_TEXT:C284($formName)
	$formName:=Choose:C955($devMode; "XMPEditorDev"; "XMPEditor")
	
	C_LONGINT:C283($windowRef)
	$windowRef:=Open form window:C675($formName; \
		Movable form dialog box:K39:8; \
		Horizontally centered:K39:1; Vertically centered:K39:4; *)
	SET WINDOW TITLE:C213($windowTitle; $windowRef)
	
	DIALOG:C40($formName)
	$success:=OK
	
	CLOSE WINDOW:C154($windowRef)
	
End if 

$0:=$success
